# Release notes

This is the list of changes to scvi-tools between each release. Full commit history
is available in the [commit logs](https://github.com/YosefLab/scvi-tools/commits/).

## Version 0.20

```{toctree}
:maxdepth: 2

v0.20.0
```

## Version 0.19

```{toctree}
:maxdepth: 2

v0.19.0
```

## Version 0.18

```{toctree}
:maxdepth: 2

v0.18.0
```

## Version 0.17

```{toctree}
:maxdepth: 2

v0.17.4
v0.17.3
v0.17.2
v0.17.1
v0.17.0
```

## Version 0.16

```{toctree}
:maxdepth: 2

v0.16.4
v0.16.3
v0.16.2
v0.16.1
v0.16.0
```

## Version 0.15

```{toctree}
:maxdepth: 2

v0.15.5
v0.15.4
v0.15.3
v0.15.2
v0.15.1
v0.15.0
```

## Version 0.14

```{toctree}
:maxdepth: 2

v0.14.6
v0.14.5
v0.14.4
v0.14.3
v0.14.2
v0.14.1
v0.14.0
```

## Version 0.13

```{toctree}
:maxdepth: 2

v0.13.0
```

## Version 0.12

```{toctree}
:maxdepth: 2

v0.12.2
v0.12.1
v0.12.0
```

## Version 0.11

```{toctree}
:maxdepth: 2

v0.11.0
```

## Version 0.10

```{toctree}
:maxdepth: 2

v0.10.1
v0.10.0
```

## Version 0.9

```{toctree}
:maxdepth: 2

v0.9.1
v0.9.0
```

## Version 0.8

```{toctree}
:maxdepth: 2

v0.8.1
v0.8.0
```

## Version 0.7

```{toctree}
:maxdepth: 2

v0.7.1
v0.7.0
```

## Pre-Version 0.7

```{toctree}
:maxdepth: 2

pre_v0.7.0
```
